@@ -668,7 +668,7 @@ void save_preferences(bool mode) {
 	filename += "qalculate-tde.cfg";
 	file = fopen(filename.c_str(), "w+");
 	if(file == NULL) {
-		fprintf(stderr, i18n("Couldn't write preferences to\n%s"), filename.c_str());
+		fprintf(stderr, i18n("Couldn't write preferences to\n%s").local8Bit(), filename.c_str());
 		return;
 	}
 	fprintf(file, "\n[General]\n");
