@@ -97,11 +97,11 @@ QalculateInsertMatrixVectorDialog::QalculateInsertMatrixVectorDialog(TQWidget *p
 	insertSelectionButton = actionButton(User1);
 	onSelectionChanged();
 
-	connect(insertSelectionButton, SIGNAL(clicked()), this, SLOT(insertSelection()));
-	connect(elementsTable, SIGNAL(selectionChanged()), this, SLOT(onSelectionChanged()));
-	connect(rowsBox, SIGNAL(valueChanged(int)), this, SLOT(rowsChanged(int)));
-	connect(columnsBox, SIGNAL(valueChanged(int)), this, SLOT(columnsChanged(int)));
-	connect(group, SIGNAL(clicked(int)), this, SLOT(typeChanged(int)));
+	connect(insertSelectionButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(insertSelection()));
+	connect(elementsTable, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(onSelectionChanged()));
+	connect(rowsBox, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(rowsChanged(int)));
+	connect(columnsBox, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(columnsChanged(int)));
+	connect(group, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(typeChanged(int)));
 
 }
 
